==> lire_1.5.orig.tar.gz: lire-1.5/spamfilter/po/lire-spamfilter.pot.pl <==
# REFERENCE: spamfilter.cfg
__( q{Statistics} );
# REFERENCE: spamfilter.cfg
__( q{Mailboxes} );
# REFERENCE: schema:spamfilter
__( q{DLF Schema for Message Store service} );
# REFERENCE: schema:spamfilter
__( q{Each DLF records in the <structname>spamfilter</structname>
   schema represents one command on the server. Not all fields will be
   meaningful for every type of action.
  } );
# REFERENCE: schema:spamfilter
__( q{Timestamp} );
# REFERENCE: schema:spamfilter
__( q{The timestamp of the event.} );
# REFERENCE: schema:spamfilter
__( q{Mail Server} );
# REFERENCE: schema:spamfilter
__( q{The hostname on which the message store is running. In the
    case of message store proxies, this will be the target server.
   } );
# REFERENCE: schema:spamfilter
__( q{Sending Host} );
# REFERENCE: schema:spamfilter
__( q{The host name of the client related to the event.} );
# REFERENCE: schema:spamfilter
__( q{Sending IP} );
# REFERENCE: schema:spamfilter
__( q{The ip address of the client related to the event.} );
# REFERENCE: schema:spamfilter
__( q{Message ID} );
# REFERENCE: schema:spamfilter
__( q{The message-id of the email.} );
# REFERENCE: schema:spamfilter
__( q{Connecting User} );
# REFERENCE: schema:spamfilter
__( q{The user name of the authenticated user associated with the
    connection. 
   } );
# REFERENCE: schema:spamfilter
__( q{Msg's Size In} );
# REFERENCE: schema:spamfilter
__( q{The size of the message when entering the spam filter.} );
# REFERENCE: schema:spamfilter
__( q{Msg's Size Out} );
# REFERENCE: schema:spamfilter
__( q{The size of the message when leaving the spam filter.} );
# REFERENCE: schema:spamfilter
__( q{Duration} );
# REFERENCE: schema:spamfilter
__( q{Time it took for the message to enter and leave the spam
    filter agent.
   } );
# REFERENCE: schema:spamfilter
__( q{Score} );
# REFERENCE: schema:spamfilter
__( q{The SPAM score attributed to the message.} );
# REFERENCE: schema:spamfilter
__( q{Spam?} );
# REFERENCE: schema:spamfilter
__( q{Was the message considered SPAM?} );
# REFERENCE: report:spamfilter:stats-delay
__( q{Delay by Period Report Specification} );
# REFERENCE: report:spamfilter:stats-delay
__( q{This report shows stats on the delay added to message delivery
   by the SPAM filter.} );
# REFERENCE: report:spamfilter:stats-delay
__( q{This parameter controls the time period over which the
     the delay statistics are aggregated..
    } );
# REFERENCE: report:spamfilter:stats-delay
__( q{Delay by $period Period} );
# REFERENCE: report:spamfilter:stats-delay
__( q{Period} );
# REFERENCE: report:spamfilter:stats-delay
__( q{Avg Delay} );
# REFERENCE: report:spamfilter:stats-delay
__( q{Max Delay} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{Total Number Of Scanned Messages} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{This report shows the total number of scanned messages.} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{This parameter controls the time period over which the
     different messages are counted.
    } );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{Messages Scanned by $period Period} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{Period} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{Messages} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{% Total} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{Total Number Of Messages Tagged As SPAM} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{This report shows the number of messages tagged as spam.} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{This parameter controls the time period over which the
     different messages are counted.
    } );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{Total Number of Messages Tagged As SPAM by $period Period} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{Period} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{Messages} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{% Total} );
# REFERENCE: report:spamfilter:stats-score-max
__( q{Maximum SPAM Score} );
# REFERENCE: report:spamfilter:stats-score-max
__( q{This report shows the maximum spam score.} );
# REFERENCE: report:spamfilter:stats-score-max
__( q{This parameter controls the time period over which the
     different users are counted.
    } );
# REFERENCE: report:spamfilter:stats-score-max
__( q{Maximum SPAM Score by $period Period } );
# REFERENCE: report:spamfilter:stats-score-max
__( q{Period} );
# REFERENCE: report:spamfilter:stats-score-max
__( q{Max Score} );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{Top Of Users Receiving SPAM} );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{This report shows which users have received most spam.} );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{This parameter controls the time period over which the
     different users are counted.
    } );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{This parameter controls the amount of people shown.
    } );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{Top $users People Receiving SPAM} );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{Spam} );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{% Total} );

==> lire_2.1.1.orig.tar.gz: lire-2.1.1/spamfilter/po/lire-spamfilter.pot.pl <==
# REFERENCE: spamfilter_default.xml
__( q{Statistics} );
# REFERENCE: spamfilter_default.xml
__( q{Mailboxes} );
# REFERENCE: schema:spamfilter
__( q{DLF Schema for Message Store service} );
# REFERENCE: schema:spamfilter
__( q{Each DLF records in the <structname>spamfilter</structname> schema represents one command on the server. Not all fields will be meaningful for every type of action. } );
# REFERENCE: schema:spamfilter
__( q{Timestamp} );
# REFERENCE: schema:spamfilter
__( q{The timestamp of the event.} );
# REFERENCE: schema:spamfilter
__( q{Mail Server} );
# REFERENCE: schema:spamfilter
__( q{The hostname on which the message store is running. In the case of message store proxies, this will be the target server. } );
# REFERENCE: schema:spamfilter
__( q{Sending Host} );
# REFERENCE: schema:spamfilter
__( q{The host name of the client related to the event.} );
# REFERENCE: schema:spamfilter
__( q{Sending IP} );
# REFERENCE: schema:spamfilter
__( q{The ip address of the client related to the event.} );
# REFERENCE: schema:spamfilter
__( q{Message ID} );
# REFERENCE: schema:spamfilter
__( q{The message-id of the email.} );
# REFERENCE: schema:spamfilter
__( q{Connecting User} );
# REFERENCE: schema:spamfilter
__( q{The user name of the authenticated user associated with the connection. } );
# REFERENCE: schema:spamfilter
__( q{Msg's Size In} );
# REFERENCE: schema:spamfilter
__( q{The size of the message when entering the spam filter.} );
# REFERENCE: schema:spamfilter
__( q{Msg's Size Out} );
# REFERENCE: schema:spamfilter
__( q{The size of the message when leaving the spam filter.} );
# REFERENCE: schema:spamfilter
__( q{Duration} );
# REFERENCE: schema:spamfilter
__( q{Time it took for the message to enter and leave the spam filter agent. } );
# REFERENCE: schema:spamfilter
__( q{Score} );
# REFERENCE: schema:spamfilter
__( q{The SPAM score attributed to the message.} );
# REFERENCE: schema:spamfilter
__( q{Spam?} );
# REFERENCE: schema:spamfilter
__( q{Was the message considered SPAM?} );
# REFERENCE: report:spamfilter:stats-delay
__( q{Delay by Period Report Specification} );
# REFERENCE: report:spamfilter:stats-delay
__( q{This report shows stats on the delay added to message delivery by the SPAM filter.} );
# REFERENCE: report:spamfilter:stats-delay
__( q{This parameter controls the time period over which the the delay statistics are aggregated.. } );
# REFERENCE: report:spamfilter:stats-delay
__( q{Delay by $period Period} );
# REFERENCE: report:spamfilter:stats-delay
__( q{Period} );
# REFERENCE: report:spamfilter:stats-delay
__( q{Avg Delay} );
# REFERENCE: report:spamfilter:stats-delay
__( q{Max Delay} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{Total Number Of Scanned Messages} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{This report shows the total number of scanned messages.} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{This parameter controls the time period over which the different messages are counted. } );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{Messages Scanned by $period Period} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{Period} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{Messages} );
# REFERENCE: report:spamfilter:stats-messages-scanned
__( q{% Total} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{Total Number Of Messages Tagged As SPAM} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{This report shows the number of messages tagged as spam.} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{This parameter controls the time period over which the different messages are counted. } );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{Total Number of Messages Tagged As SPAM by $period Period} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{Period} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{Messages} );
# REFERENCE: report:spamfilter:stats-messages-spamsfound
__( q{% Total} );
# REFERENCE: report:spamfilter:stats-score-max
__( q{Maximum SPAM Score} );
# REFERENCE: report:spamfilter:stats-score-max
__( q{This report shows the maximum spam score.} );
# REFERENCE: report:spamfilter:stats-score-max
__( q{This parameter controls the time period over which the different users are counted. } );
# REFERENCE: report:spamfilter:stats-score-max
__( q{Maximum SPAM Score by $period Period} );
# REFERENCE: report:spamfilter:stats-score-max
__( q{Period} );
# REFERENCE: report:spamfilter:stats-score-max
__( q{Max Score} );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{Top Of Users Receiving SPAM} );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{This report shows which users have received most spam.} );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{This parameter controls the time period over which the different users are counted. } );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{This parameter controls the amount of people shown. } );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{Top $users People Receiving SPAM} );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{Spam} );
# REFERENCE: report:spamfilter:top-receiving-spam
__( q{% Total} );
